@@ -18,6 +18,7 @@ from .automation import (
     GeckoPump,
     GeckoSensor,
     GeckoBinarySensor,
+    GeckoErrorSensor,
     GeckoSwitch,
     GeckoWaterCare,
     GeckoReminders,
@@ -80,6 +81,7 @@ __all__ = [
     "GeckoPump",
     "GeckoSensor",
     "GeckoBinarySensor",
+    "GeckoErrorSensor",
     "GeckoSwitch",
     "GeckoWaterCare",
     "GeckoReminders",
