@@ -14,28 +14,7 @@ from . import (
 
 # Constants for this class
 ACQFFT = "".join(chr(c) for c in [65, 109, 80, 109])
-AFIKJP = "".join(
-    chr(c)
-    for c in [
-        68,
-        101,
-        97,
-        108,
-        101,
-        114,
-        76,
-        111,
-        99,
-        107,
-        83,
-        117,
-        112,
-        112,
-        111,
-        114,
-        116,
-    ]
-)
+AFIKJP = 46
 AHEOCT = "".join(chr(c) for c in [79, 117, 116, 52, 67, 117, 114])
 AJVDQL = "".join(
     chr(c)
@@ -62,10 +41,10 @@ AJVDQL = "".join(
     ]
 )
 AKQXPI = "".join(chr(c) for c in [79, 117, 116, 50])
+AKSTSE = "".join(chr(c) for c in [52])
 AMJMAO = "".join(chr(c) for c in [70, 50])
 AONPYY = "".join(chr(c) for c in [72, 105])
 ASSAKQ = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
-ATDZXN = "".join(chr(c) for c in [90, 111, 110, 101, 50, 76, 101, 100])
 AWBSIR = 84
 BFEGZU = 48
 BIAMJM = 83
@@ -73,28 +52,6 @@ BJEUTO = "".join(chr(c) for c in [71, 101, 110, 101, 114, 105, 99])
 BLKXSJ = "".join(chr(c) for c in [84, 101, 109, 112, 85, 110, 105, 116, 115])
 BMJVHF = "".join(chr(c) for c in [79, 117, 116, 49])
 BQFYLJ = 88
-BQNRXC = "".join(
-    chr(c)
-    for c in [
-        81,
-        117,
-        105,
-        99,
-        107,
-        79,
-        102,
-        102,
-        75,
-        101,
-        121,
-        69,
-        110,
-        97,
-        98,
-        108,
-        101,
-    ]
-)
 BQSNQL = "".join(chr(c) for c in [70, 105, 108, 116, 68, 117, 114, 50])
 BSIRYX = 85
 BSKSOK = 17
@@ -130,7 +87,9 @@ BXYBQS = 4
 BYGDSB = 43
 CBFEGZ = "".join(chr(c) for c in [65, 117, 120, 84, 105, 109, 101, 79, 117, 116])
 CCPQIP = "".join(chr(c) for c in [79, 51, 85, 115, 97, 103, 101])
-CHWDAF = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
+CHWDAF = "".join(
+    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
+)
 CPQIPO = 28
 CQBMJV = 0
 CQFFTT = "".join(chr(c) for c in [50, 52, 104])
@@ -138,8 +97,10 @@ CTHBSK = "".join(chr(c) for c in [79, 117, 116, 72, 116, 82, 67, 117, 114])
 CVYYPI = "".join(chr(c) for c in [80, 52, 72])
 CWAONP = "".join(chr(c) for c in [80, 117, 114, 103, 101, 83, 112, 101, 101, 100])
 CXQIEF = "".join(chr(c) for c in [79, 117, 116, 53])
-DAFIKJ = 46
-DGKEAK = "".join(chr(c) for c in [49])
+DAFIKJ = "".join(
+    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
+)
+DGKEAK = 127
 DJQRJJ = "".join(
     chr(c) for c in [66, 114, 101, 97, 107, 101, 114, 67, 104, 97, 110, 103, 101]
 )
@@ -149,8 +110,8 @@ DQLAII = 76
 DSBDJQ = "".join(
     chr(c) for c in [78, 79, 95, 82, 69, 83, 84, 82, 73, 67, 84, 73, 79, 78]
 )
-DZXNQT = "".join(chr(c) for c in [90, 111, 110, 101, 50, 84, 121, 112, 101])
-EAKSTS = "".join(chr(c) for c in [52])
+DZXNQT = 124
+EAKSTS = "".join(chr(c) for c in [51])
 ECVYYP = "".join(chr(c) for c in [80, 51, 76])
 EFJTAC = 62
 EGZUQE = 32
@@ -160,6 +121,7 @@ EKCWAO = "".join(
 )
 EKVKZI = "".join(chr(c) for c in [85, 68, 80, 114, 111, 103, 69, 99, 111, 110])
 ELHBQN = "".join(chr(c) for c in [84, 105, 116, 97, 110, 95, 83, 112, 97, 115])
+EMCGET = 60
 EOCTHB = "".join(chr(c) for c in [79, 117, 116, 53, 67, 117, 114])
 EUTOPH = "".join(
     chr(c) for c in [69, 110, 100, 108, 101, 115, 115, 80, 111, 111, 108, 115]
@@ -176,7 +138,28 @@ FFTTID = "".join(
     chr(c)
     for c in [65, 109, 98, 105, 97, 110, 116, 79, 72, 84, 114, 105, 103, 65, 68, 67]
 )
-FIKJPU = 47
+FIKJPU = "".join(
+    chr(c)
+    for c in [
+        68,
+        101,
+        97,
+        108,
+        101,
+        114,
+        76,
+        111,
+        99,
+        107,
+        83,
+        117,
+        112,
+        112,
+        111,
+        114,
+        116,
+    ]
+)
 FJTACC = "".join(chr(c) for c in [68, 114, 97, 105, 110, 77, 111, 100, 101])
 FMNHTB = "".join(chr(c) for c in [68, 105, 115, 97, 98, 108, 101])
 FTHECV = "".join(chr(c) for c in [80, 50, 72])
@@ -185,19 +168,18 @@ FTTIDU = 64
 FWRKIN = "".join(chr(c) for c in [70, 49, 76, 105, 110, 101])
 FXQGLR = "".join(chr(c) for c in [79, 117, 116, 49, 67, 117, 114])
 FYLJUI = 89
-FZDGKE = "".join(
-    chr(c) for c in [78, 117, 109, 98, 101, 114, 79, 102, 90, 111, 110, 101, 115]
-)
+FZDGKE = "".join(chr(c) for c in [90, 111, 110, 101, 52, 84, 121, 112, 101])
 GDSBDJ = "".join(
     chr(c) for c in [67, 111, 110, 102, 105, 103, 67, 104, 97, 110, 103, 101]
 )
-GKEAKS = "".join(chr(c) for c in [50])
+GKEAKS = "".join(chr(c) for c in [49])
 GLRAHE = 37
 GSELHB = "".join(chr(c) for c in [65, 115, 112, 101, 110])
 GTYIYW = "".join(chr(c) for c in [66, 101, 108, 108, 97, 103, 105, 111])
 GVUNXN = "".join(chr(c) for c in [80, 68, 67])
 GYOUSP = "".join(chr(c) for c in [69, 99, 111, 110, 84, 121, 112, 101])
 GZUQEX = "".join(chr(c) for c in [80, 117, 114, 103, 101, 79, 110, 108, 121])
+HBQNRX = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 95, 83, 112, 97, 115])
 HBSKSO = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116])
 HECVYY = "".join(chr(c) for c in [80, 51, 72])
 HEOCTH = 39
@@ -205,6 +187,7 @@ HFTHEC = "".join(chr(c) for c in [80, 49, 76])
 HIUSOO = 55
 HTBJEU = "".join(chr(c) for c in [67, 117, 115, 116, 111, 109, 101, 114, 73, 68])
 HUGTYI = "".join(chr(c) for c in [66, 97, 114, 101, 102, 111, 111, 116])
+HWDAFI = "".join(chr(c) for c in [83, 72, 79, 87, 95, 65, 76, 76, 95, 77, 83, 71])
 HXEKVK = "".join(
     chr(c) for c in [79, 85, 84, 83, 73, 68, 69, 95, 70, 73, 76, 84, 69, 82]
 )
@@ -222,7 +205,7 @@ IGYOUS = 68
 IIDNIB = "".join(chr(c) for c in [77, 97, 115, 116, 101, 114, 83, 108, 97, 118, 101])
 IJUGSE = "".join(chr(c) for c in [67, 108, 101, 97, 114, 119, 97, 116, 101, 114])
 IKFWRK = "".join(chr(c) for c in [70, 51, 67, 117, 114, 114, 101, 110, 116])
-IKJPUN = "".join(chr(c) for c in [76, 111, 99, 107, 69, 110, 97, 98, 108, 101, 100])
+IKJPUN = 47
 ILXWAJ = "".join(
     chr(c) for c in [79, 102, 102, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
 )
@@ -250,7 +233,7 @@ JMCBFE = "".join(
     for c in [87, 97, 116, 101, 114, 102, 97, 108, 108, 84, 105, 109, 101, 79, 117, 116]
 )
 JNIBXY = "".join(chr(c) for c in [70, 105, 108, 116, 70, 114, 101, 113])
-JPUNRJ = "".join(chr(c) for c in [90, 111, 110, 101, 49, 76, 101, 100])
+JPUNRJ = 121
 JQRJJJ = "".join(
     chr(c)
     for c in [
@@ -287,11 +270,11 @@ JVYFCR = "".join(chr(c) for c in [66, 76, 85, 69])
 JWMNZM = "".join(chr(c) for c in [72, 101, 97, 116, 101, 114, 80, 117, 109, 112])
 JYKLGQ = "".join(chr(c) for c in [85, 76, 95, 67, 69])
 JYMOUN = "".join(chr(c) for c in [84, 111, 103, 103, 108, 101])
-JZTATD = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
-KEAKST = "".join(chr(c) for c in [51])
+JZTATD = "".join(chr(c) for c in [90, 111, 110, 101, 49, 84, 121, 112, 101])
+KEAKST = "".join(chr(c) for c in [50])
 KFWRKI = 100
 KINEJN = "".join(chr(c) for c in [70, 50, 76, 105, 110, 101])
-KJPUNR = 121
+KJPUNR = "".join(chr(c) for c in [76, 111, 99, 107, 69, 110, 97, 98, 108, 101, 100])
 KLGQPL = "".join(chr(c) for c in [85, 76])
 KMLOIJ = "".join(
     chr(c) for c in [83, 112, 97, 95, 73, 110, 100, 117, 115, 116, 114, 105, 101, 115]
@@ -343,7 +326,7 @@ LSXUJU = 27
 LXWAJV = 1
 MAOAWB = "".join(chr(c) for c in [76, 105, 110, 101, 50])
 MCBFEG = 118
-MFZDGK = "".join(chr(c) for c in [90, 111, 110, 101, 52, 84, 121, 112, 101])
+MFZDGK = 126
 MHXEKV = 71
 MJIGYO = 66
 MJMAOA = "".join(chr(c) for c in [70, 51])
@@ -389,37 +372,9 @@ NPYYLI = "".join(chr(c) for c in [79, 84, 84, 114, 105, 103, 103, 101, 114, 71])
 NQGVUN = "".join(chr(c) for c in [77, 65, 65, 88])
 NQJYMO = 30
 NQLNMH = 8
-NQTMFZ = "".join(chr(c) for c in [90, 111, 110, 101, 51, 84, 121, 112, 101])
-NRXCHW = "".join(
-    chr(c)
-    for c in [
-        77,
-        111,
-        100,
-        101,
-        75,
-        101,
-        121,
-        65,
-        115,
-        73,
-        110,
-        118,
-        101,
-        114,
-        116,
-        68,
-        105,
-        115,
-        112,
-        108,
-        97,
-        121,
-        75,
-        101,
-        121,
-    ]
-)
+NQTMFZ = 125
+NRJZTA = "".join(chr(c) for c in [82, 71, 66])
+NRXCHW = 45
 NXNKML = "".join(chr(c) for c in [83, 117, 110, 114, 97, 110, 115])
 NZMJIG = 35
 OAWBSI = "".join(chr(c) for c in [79, 117, 116, 50, 70, 117, 115, 101])
@@ -466,7 +421,7 @@ PIVLAS = "".join(chr(c) for c in [76, 49, 50, 48])
 PLSPFT = 52
 POUYNQ = "".join(chr(c) for c in [79, 51, 80, 117, 109, 112])
 PQIPOU = "".join(chr(c) for c in [70, 105, 108, 116, 101, 114])
-PUNRJZ = 123
+PUNRJZ = "".join(chr(c) for c in [90, 111, 110, 101, 49, 76, 101, 100])
 PYYLIU = 58
 QBMJVH = "".join(chr(c) for c in [65, 76, 76])
 QEXLSX = "".join(
@@ -483,20 +438,67 @@ QLAIID = "".join(
 )
 QLNMHX = "".join(chr(c) for c in [69, 99, 111, 110, 68, 117, 114])
 QNRSJM = "".join(chr(c) for c in [79, 119, 110])
-QNRXCH = 45
+QNRXCH = "".join(
+    chr(c)
+    for c in [
+        81,
+        117,
+        105,
+        99,
+        107,
+        79,
+        102,
+        102,
+        75,
+        101,
+        121,
+        69,
+        110,
+        97,
+        98,
+        108,
+        101,
+    ]
+)
 QPLSPF = "".join(chr(c) for c in [78, 98, 80, 104, 97, 115, 101, 115])
 QRJJJV = "".join(chr(c) for c in [79, 70, 70])
 QSNQLN = 23
-QTMFZD = "".join(chr(c) for c in [90, 111, 110, 101, 52, 76, 101, 100])
+QTMFZD = "".join(chr(c) for c in [90, 111, 110, 101, 51, 84, 121, 112, 101])
 QXPICX = "".join(chr(c) for c in [79, 117, 116, 51])
 RAHEOC = 38
 RJHIUS = 54
 RJJJVY = "".join(chr(c) for c in [82, 69, 68])
-RJZTAT = "".join(chr(c) for c in [90, 111, 110, 101, 49, 84, 121, 112, 101])
 RSJMCB = 0
 RTFMNH = 8
 RXCHWD = "".join(
-    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
+    chr(c)
+    for c in [
+        77,
+        111,
+        100,
+        101,
+        75,
+        101,
+        121,
+        65,
+        115,
+        73,
+        110,
+        118,
+        101,
+        114,
+        116,
+        68,
+        105,
+        115,
+        112,
+        108,
+        97,
+        121,
+        75,
+        101,
+        121,
+    ]
 )
 RYXBQF = "".join(chr(c) for c in [79, 117, 116, 53, 70, 117, 115, 101])
 SBDJQR = "".join(
@@ -504,7 +506,6 @@ SBDJQR = "".join(
     for c in [80, 65, 83, 83, 87, 79, 82, 68, 95, 80, 82, 79, 84, 69, 67, 84, 69, 68]
 )
 SELHBQ = "".join(chr(c) for c in [84, 104, 101, 114, 109, 111, 83, 112, 97, 115])
-SEMCGE = 60
 SIFJBI = 74
 SIRYXB = "".join(chr(c) for c in [79, 117, 116, 52, 70, 117, 115, 101])
 SJMCBF = 2
@@ -524,8 +525,9 @@ SSUHBV = "".join(
 SUHBVW = "".join(chr(c) for c in [70, 114, 101, 101, 80, 117, 109, 112, 75, 101, 121])
 SXUJUT = "".join(chr(c) for c in [83, 84, 65, 78, 68, 65, 82, 68])
 TACCPQ = "".join(chr(c) for c in [80, 49])
+TATDZX = "".join(chr(c) for c in [83, 84, 65, 84, 85, 83])
 TBJEUT = 44
-TDZXNQ = 124
+TDZXNQ = "".join(chr(c) for c in [90, 111, 110, 101, 50, 76, 101, 100])
 TFMNHT = "".join(
     chr(c)
     for c in [
@@ -554,7 +556,7 @@ THBSKS = 42
 THECVY = "".join(chr(c) for c in [80, 50, 76])
 TIACQF = "".join(chr(c) for c in [84, 105, 109, 101, 70, 111, 114, 109, 97, 116])
 TIDUBS = "".join(chr(c) for c in [66, 111, 116, 104, 83, 112, 101, 101, 100, 115])
-TMFZDG = 126
+TMFZDG = "".join(chr(c) for c in [90, 111, 110, 101, 52, 76, 101, 100])
 TOPHUG = "".join(chr(c) for c in [65, 108, 112, 115])
 TSIFJB = "".join(chr(c) for c in [73, 110, 112, 117, 116, 77, 101, 110, 117])
 TTIDUB = "".join(
@@ -599,7 +601,7 @@ UGTYIY = "".join(chr(c) for c in [66, 101, 97, 99, 104, 99, 111, 109, 98, 101, 1
 UHBVWV = "".join(chr(c) for c in [76, 97, 115, 116, 80, 117, 109, 112, 75, 101, 121])
 UIKFWR = 99
 UNBLKX = "".join(chr(c) for c in [83, 101, 116, 112, 111, 105, 110, 116, 71])
-UNRJZT = "".join(chr(c) for c in [82, 71, 66])
+UNRJZT = 123
 UNXNKM = "".join(chr(c) for c in [83, 116, 114, 111, 110, 103])
 UOJRJH = "".join(chr(c) for c in [76, 105, 103, 104, 116, 73, 110, 116, 115])
 UQEXLS = "".join(chr(c) for c in [70, 105, 108, 116, 80, 49])
@@ -674,9 +676,6 @@ VYYPIP = "".join(chr(c) for c in [80, 52, 76])
 WAJVDQ = 3
 WAONPY = "".join(chr(c) for c in [76, 111])
 WBSIRY = "".join(chr(c) for c in [79, 117, 116, 51, 70, 117, 115, 101])
-WDAFIK = "".join(
-    chr(c) for c in [75, 101, 121, 112, 97, 100, 79, 112, 116, 105, 111, 110, 115, 52]
-)
 WIVDNQ = "".join(chr(c) for c in [74, 97, 99, 117, 122, 122, 105])
 WJYKLG = 26
 WMNZMJ = 31
@@ -687,12 +686,12 @@ WVUBYG = "".join(
 )
 XBQFYL = "".join(chr(c) for c in [68, 105, 114, 101, 99, 116, 70, 117, 115, 101])
 XCHWDA = "".join(
-    chr(c) for c in [72, 73, 68, 69, 95, 68, 69, 84, 65, 73, 76, 69, 68, 95, 77, 83, 71]
+    chr(c) for c in [73, 110, 102, 111, 77, 115, 103, 67, 111, 110, 102, 105, 103]
 )
 XFEFJT = 61
 XLSXUJ = "".join(chr(c) for c in [67, 112, 85, 115, 97, 103, 101])
 XNKMLO = "".join(chr(c) for c in [83, 117, 110, 114, 105, 115, 101])
-XNQTMF = 125
+XNQTMF = "".join(chr(c) for c in [90, 111, 110, 101, 51, 76, 101, 100])
 XPICXQ = 14
 XQGLRA = 36
 XQIEFX = 16
@@ -751,7 +750,9 @@ YYPIPI = "".join(chr(c) for c in [80, 53])
 ZCQBMJ = "".join(
     chr(c) for c in [67, 111, 110, 102, 105, 103, 78, 117, 109, 98, 101, 114]
 )
-ZDGKEA = 127
+ZDGKEA = "".join(
+    chr(c) for c in [78, 117, 109, 98, 101, 114, 79, 102, 90, 111, 110, 101, 115]
+)
 ZILXWA = "".join(
     chr(c)
     for c in [83, 111, 97, 107, 79, 110, 67, 117, 115, 116, 111, 109, 75, 101, 121]
@@ -759,37 +760,15 @@ ZILXWA = "".join(
 ZMJIGY = "".join(
     chr(c) for c in [77, 105, 110, 83, 101, 116, 112, 111, 105, 110, 116, 71]
 )
-ZTATDZ = "".join(chr(c) for c in [83, 84, 65, 84, 85, 83])
+ZTATDZ = "".join(chr(c) for c in [78, 79, 82, 77, 65, 76])
 ZUQEXL = "".join(chr(c) for c in [70, 105, 108, 116, 67, 80])
-ZXNQTM = "".join(chr(c) for c in [90, 111, 110, 101, 51, 76, 101, 100])
+ZXNQTM = "".join(chr(c) for c in [90, 111, 110, 101, 50, 84, 121, 112, 101])
 ACCPQI = [JVHFTH, TACCPQ, PIPIVL]
 AIIDNI = [QLAIID, LAIIDN]
-AKSTSE = [VLASSA, DGKEAK, GKEAKS, KEAKST, EAKSTS]
 AOAWBS = [IAMJMA, AMJMAO, MJMAOA, VLASSA, VLASSA, VLASSA, JMAOAW, MAOAWB]
+ATDZXN = [ZTATDZ, TATDZX]
 BDJQRJ = [DSBDJQ, SBDJQR]
-CRTFMN = [QRJJJV, RJJJVY, JJJVYF, JJVYFC, JVYFCR, VYFCRT, YFCRTF, FCRTFM]
-DUBSSU = [TIDUBS, IDUBSS]
-EFXQGL = [
-    JVHFTH,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    VLASSA,
-    IVLASS,
-]
-EXLSXU = [GZUQEX, ZUQEXL, UQEXLS, QEXLSX]
-FJBIAM = [QJYMOU, IFJBIA]
-GQPLSP = [KLGQPL, LGQPLS]
-HBQNRX = [
+BQNRXC = [
     BJEUTO,
     JEUTOP,
     EUTOPH,
@@ -830,7 +809,30 @@ HBQNRX = [
     SELHBQ,
     ELHBQN,
     LHBQNR,
+    HBQNRX,
 ]
+CRTFMN = [QRJJJV, RJJJVY, JJJVYF, JJVYFC, JVYFCR, VYFCRT, YFCRTF, FCRTFM]
+DUBSSU = [TIDUBS, IDUBSS]
+EFXQGL = [
+    JVHFTH,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    VLASSA,
+    IVLASS,
+]
+EXLSXU = [GZUQEX, ZUQEXL, UQEXLS, QEXLSX]
+FJBIAM = [QJYMOU, IFJBIA]
+GQPLSP = [KLGQPL, LGQPLS]
 HBVWVU = [SUHBVW, UHBVWV]
 HUOJRJ = [
     VLASSA,
@@ -850,16 +852,15 @@ HUOJRJ = [
     VLASSA,
     PHUOJR,
 ]
-HWDAFI = [XCHWDA, CHWDAF, VLASSA, VLASSA]
 IBXTIA = [VLASSA, DNIBXT, NIBXTI]
 IPOUYN = [PQIPOU, QIPOUY]
 KCWAON = [TYEKCW, YEKCWA, EKCWAO]
-KSTSEM = [BMJVHF, AKQXPI, QXPICX, PICXQI, CXQIEF, QIEFXQ, HBSKSO, OKPHUO]
+KSTSEM = [VLASSA, GKEAKS, KEAKST, EAKSTS, AKSTSE]
 NHTBJE = [FMNHTB, MNHTBJ]
-NRJZTA = [UNRJZT, FCRTFM]
 NRSJMC = [OQNRSJ, QNRSJM]
 ONPYYL = [WAONPY, AONPYY]
 QFFTTI = [JVHFTH, ACQFFT, CQFFTT]
+RJZTAT = [NRJZTA, FCRTFM]
 RKINEJ = [VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, VLASSA, JMAOAW, MAOAWB]
 SAKQXP = [
     JVHFTH,
@@ -891,6 +892,7 @@ SAKQXP = [
     ASSAKQ,
     SSAKQX,
 ]
+SEMCGE = []
 SJWMNZ = [KXSJWM, XSJWMN]
 SKSOKP = [
     JVHFTH,
@@ -906,12 +908,12 @@ SKSOKP = [
     VLASSA,
     PIPIVL,
 ]
-STSEMC = [PHUOJR]
-TATDZX = [JZTATD, ZTATDZ]
-TSEMCG = []
+STSEMC = [BMJVHF, AKQXPI, QXPICX, PICXQI, CXQIEF, QIEFXQ, HBSKSO, OKPHUO]
+TSEMCG = [PHUOJR]
 UJUTYE = [SXUJUT, XUJUTY]
 USPBWJ = [QJYMOU, OUSPBW]
 UYNQJY = [PIPIVL, TACCPQ]
+WDAFIK = [CHWDAF, HWDAFI, VLASSA, VLASSA]
 XEKVKZ = [JVHFTH, SXUJUT, HXEKVK]
 YMOUNB = [QJYMOU, JYMOUN]
 
@@ -922,11 +924,11 @@ class GeckoConfigStruct:
 
     @property
     def version(self):
-        return SEMCGE
+        return EMCGET
 
     @property
     def output_keys(self):
-        return KSTSEM
+        return STSEMC
 
     @property
     def accessors(self):
@@ -1130,45 +1132,45 @@ class GeckoConfigStruct:
             TFMNHT: GeckoEnumStructAccessor(
                 self.struct, TFMNHT, BYGDSB, VUBYGD, NHTBJE, None, SJMCBF, QBMJVH
             ),
-            BQNRXC: GeckoBoolStructAccessor(
-                self.struct, BQNRXC, QNRXCH, RSJMCB, QBMJVH
+            QNRXCH: GeckoBoolStructAccessor(
+                self.struct, QNRXCH, NRXCHW, RSJMCB, QBMJVH
             ),
-            NRXCHW: GeckoBoolStructAccessor(
-                self.struct, NRXCHW, QNRXCH, LXWAJV, QBMJVH
+            RXCHWD: GeckoBoolStructAccessor(
+                self.struct, RXCHWD, NRXCHW, LXWAJV, QBMJVH
             ),
-            RXCHWD: GeckoEnumStructAccessor(
-                self.struct, RXCHWD, QNRXCH, SJMCBF, HWDAFI, None, BSSUHB, QBMJVH
+            XCHWDA: GeckoEnumStructAccessor(
+                self.struct, XCHWDA, NRXCHW, SJMCBF, WDAFIK, None, BSSUHB, QBMJVH
             ),
-            WDAFIK: GeckoByteStructAccessor(self.struct, WDAFIK, DAFIKJ, QBMJVH),
-            AFIKJP: GeckoBoolStructAccessor(
-                self.struct, AFIKJP, FIKJPU, RSJMCB, QBMJVH
+            DAFIKJ: GeckoByteStructAccessor(self.struct, DAFIKJ, AFIKJP, QBMJVH),
+            FIKJPU: GeckoBoolStructAccessor(
+                self.struct, FIKJPU, IKJPUN, RSJMCB, QBMJVH
             ),
-            IKJPUN: GeckoByteStructAccessor(self.struct, IKJPUN, KJPUNR, QBMJVH),
-            JPUNRJ: GeckoEnumStructAccessor(
-                self.struct, JPUNRJ, PUNRJZ, RSJMCB, NRJZTA, None, SJMCBF, None
+            KJPUNR: GeckoByteStructAccessor(self.struct, KJPUNR, JPUNRJ, QBMJVH),
+            PUNRJZ: GeckoEnumStructAccessor(
+                self.struct, PUNRJZ, UNRJZT, RSJMCB, RJZTAT, None, SJMCBF, None
             ),
-            RJZTAT: GeckoEnumStructAccessor(
-                self.struct, RJZTAT, PUNRJZ, LXWAJV, TATDZX, None, SJMCBF, None
+            JZTATD: GeckoEnumStructAccessor(
+                self.struct, JZTATD, UNRJZT, LXWAJV, ATDZXN, None, SJMCBF, None
             ),
-            ATDZXN: GeckoEnumStructAccessor(
-                self.struct, ATDZXN, TDZXNQ, RSJMCB, NRJZTA, None, SJMCBF, None
-            ),
-            DZXNQT: GeckoEnumStructAccessor(
-                self.struct, DZXNQT, TDZXNQ, LXWAJV, TATDZX, None, SJMCBF, None
+            TDZXNQ: GeckoEnumStructAccessor(
+                self.struct, TDZXNQ, DZXNQT, RSJMCB, RJZTAT, None, SJMCBF, None
             ),
             ZXNQTM: GeckoEnumStructAccessor(
-                self.struct, ZXNQTM, XNQTMF, RSJMCB, NRJZTA, None, SJMCBF, None
+                self.struct, ZXNQTM, DZXNQT, LXWAJV, ATDZXN, None, SJMCBF, None
             ),
-            NQTMFZ: GeckoEnumStructAccessor(
-                self.struct, NQTMFZ, XNQTMF, LXWAJV, TATDZX, None, SJMCBF, None
+            XNQTMF: GeckoEnumStructAccessor(
+                self.struct, XNQTMF, NQTMFZ, RSJMCB, RJZTAT, None, SJMCBF, None
             ),
             QTMFZD: GeckoEnumStructAccessor(
-                self.struct, QTMFZD, TMFZDG, RSJMCB, NRJZTA, None, SJMCBF, None
+                self.struct, QTMFZD, NQTMFZ, LXWAJV, ATDZXN, None, SJMCBF, None
             ),
-            MFZDGK: GeckoEnumStructAccessor(
-                self.struct, MFZDGK, TMFZDG, LXWAJV, TATDZX, None, SJMCBF, None
+            TMFZDG: GeckoEnumStructAccessor(
+                self.struct, TMFZDG, MFZDGK, RSJMCB, RJZTAT, None, SJMCBF, None
             ),
             FZDGKE: GeckoEnumStructAccessor(
-                self.struct, FZDGKE, ZDGKEA, RSJMCB, AKSTSE, None, RTFMNH, None
+                self.struct, FZDGKE, MFZDGK, LXWAJV, ATDZXN, None, SJMCBF, None
+            ),
+            ZDGKEA: GeckoEnumStructAccessor(
+                self.struct, ZDGKEA, DGKEAK, RSJMCB, KSTSEM, None, RTFMNH, None
             ),
         }
