@@ -36,7 +36,6 @@ ACCPQI = "".join(
         114,
     ]
 )
-ACMCVD = 53
 ACQFFT = "".join(
     chr(c) for c in [80, 97, 99, 107, 67, 111, 110, 102, 105, 103, 76, 105, 98]
 )
@@ -119,12 +118,13 @@ CBFEGZ = "".join(chr(c) for c in [85, 78, 76, 79, 67, 75])
 CCPQIP = "".join(chr(c) for c in [67, 80, 79, 84])
 CGETIX = "".join(chr(c) for c in [67, 70, 71, 50, 52])
 CHWDAF = "".join(chr(c) for c in [67, 70, 71, 53])
-CMCVDS = 256
+CMCVDS = 53
 CPQIPO = 274
 CQBMJV = 317
 CQFFTT = 295
 CRTFMN = 361
 CTHBSK = 303
+CVDSSR = 479
 CVYYPI = "".join(chr(c) for c in [83, 116, 105, 99, 107, 66, 97, 110, 107])
 CWAONP = 266
 CXQIEF = "".join(chr(c) for c in [85, 100, 80, 51])
@@ -384,7 +384,7 @@ LXWAJV = "".join(chr(c) for c in [80, 50, 50])
 MAOAWB = "".join(chr(c) for c in [82, 104, 72, 119, 72, 76])
 MCBFEG = 310
 MCGETI = 471
-MCVDSS = 479
+MCVDSS = 256
 MFZDGK = "".join(chr(c) for c in [67, 70, 71, 49, 55])
 MHXEKV = "".join(chr(c) for c in [51, 50, 75])
 MJIGYO = "".join(chr(c) for c in [67, 104, 101, 99, 107, 70, 108, 111])
@@ -695,6 +695,36 @@ ZTATDZ = "".join(chr(c) for c in [67, 70, 71, 49, 50])
 ZUQEXL = 262
 ZVOACM = "".join(chr(c) for c in [76, 73])
 ZXNQTM = 462
+ACMCVD = [
+    YLJUIK,
+    FJBIAM,
+    IAMJMA,
+    GQPLSP,
+    BLKXSJ,
+    FYLJUI,
+    LJUIKF,
+    MNZMJI,
+    ACCPQI,
+    TSIFJB,
+    LSPFTS,
+    SPBWJY,
+    OUSPBW,
+    BQFYLJ,
+    PLSPFT,
+    SIFJBI,
+    FTSIFJ,
+    YKLGQP,
+    AMJMAO,
+    WJYKLG,
+    PBWJYK,
+    JBIAMJ,
+    AOAWBS,
+    BIAMJM,
+    BWJYKL,
+    PFTSIF,
+    QPLSPF,
+    KLGQPL,
+]
 EGZUQE = [CBFEGZ, BFEGZU, FEGZUQ]
 EKVKZI = [NMHXEK, MHXEKV, HXEKVK, XEKVKZ]
 EXLSXU = [UQEXLS, QEXLSX]
@@ -861,16 +891,16 @@ class GeckoLogStruct:
 
     @property
     def version(self):
-        return ACMCVD
-
-    @property
-    def begin(self):
         return CMCVDS
 
     @property
-    def end(self):
+    def begin(self):
         return MCVDSS
 
+    @property
+    def end(self):
+        return CVDSSR
+
     @property
     def all_device_keys(self):
         return VOACMC
@@ -879,6 +909,10 @@ class GeckoLogStruct:
     def user_demand_keys(self):
         return OACMCV
 
+    @property
+    def error_keys(self):
+        return ACMCVD
+
     @property
     def accessors(self):
         return {
