@@ -61,6 +61,7 @@ AWBSIR = "".join(
     chr(c) for c in [82, 104, 72, 114, 75, 105, 110, 78, 111, 70, 108, 111]
 )
 AZMKQT = "".join(chr(c) for c in [67, 70, 71, 51, 48])
+BBEKBD = 479
 BDJQRJ = 320
 BFEGZU = "".join(chr(c) for c in [80, 65, 82, 84, 73, 65, 76])
 BHZVOA = "".join(chr(c) for c in [67, 70, 71, 50, 50])
@@ -190,7 +191,6 @@ HEOCTH = "".join(chr(c) for c in [85, 100, 76, 105])
 HFTHEC = "".join(chr(c) for c in [])
 HIUSOO = 260
 HTBJEU = "".join(chr(c) for c in [83, 79, 117, 116, 52])
-HTZBBE = 53
 HUGTYI = 335
 HUOJRJ = "".join(chr(c) for c in [76, 79, 87])
 HWDAFI = "".join(chr(c) for c in [83, 79, 117, 116, 49, 49, 67, 117, 114])
@@ -525,7 +525,7 @@ TSIFJB = "".join(
 )
 TTIDUB = 357
 TYIYWS = "".join(chr(c) for c in [83, 79, 117, 116, 51, 67, 117, 114])
-TZBBEK = 256
+TZBBEK = 53
 UBSSUH = "".join(chr(c) for c in [75, 56])
 UBYGDS = 358
 UGSELH = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 50])
@@ -678,7 +678,7 @@ YYLIUX = "".join(
     ]
 )
 YYPIPI = "".join(chr(c) for c in [81, 117, 105, 101, 116, 83, 116, 97, 116, 101])
-ZBBEKB = 479
+ZBBEKB = 256
 ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
 ZDGKEA = 456
 ZILXWA = "".join(chr(c) for c in [67, 69])
@@ -711,6 +711,37 @@ EXLSXU = [UQEXLS, QEXLSX]
 FFTTID = [CQFFTT, QFFTTI]
 FXQGLR = [IVLASS, AKQXPI]
 GLRAHE = [IVLASS, QGLRAH]
+HTZBBE = [
+    LJUIKF,
+    FJBIAM,
+    IAMJMA,
+    GQPLSP,
+    BLKXSJ,
+    IRYXBQ,
+    YLJUIK,
+    JUIKFW,
+    MNZMJI,
+    ACCPQI,
+    TSIFJB,
+    LSPFTS,
+    SPBWJY,
+    OUSPBW,
+    QFYLJU,
+    PLSPFT,
+    SIFJBI,
+    FTSIFJ,
+    YKLGQP,
+    AMJMAO,
+    WJYKLG,
+    PBWJYK,
+    JBIAMJ,
+    AOAWBS,
+    BIAMJM,
+    BWJYKL,
+    PFTSIF,
+    QPLSPF,
+    KLGQPL,
+]
 ILXWAJ = [KZILXW, ZILXWA]
 IUSOOQ = [IVLASS, PHUOJR]
 JUGSEL = [
@@ -854,16 +885,16 @@ class GeckoLogStruct:
 
     @property
     def version(self):
-        return HTZBBE
-
-    @property
-    def begin(self):
         return TZBBEK
 
     @property
-    def end(self):
+    def begin(self):
         return ZBBEKB
 
+    @property
+    def end(self):
+        return BBEKBD
+
     @property
     def all_device_keys(self):
         return DKHTZB
@@ -872,6 +903,10 @@ class GeckoLogStruct:
     def user_demand_keys(self):
         return KHTZBB
 
+    @property
+    def error_keys(self):
+        return HTZBBE
+
     @property
     def accessors(self):
         return {
