@@ -165,7 +165,6 @@ EAKSTS = "".join(chr(c) for c in [67, 70, 71, 48])
 ECVYYP = "".join(
     chr(c) for c in [73, 110, 115, 116, 97, 108, 108, 101, 114, 79, 112, 116]
 )
-EEZFET = 59
 EFJTAC = "".join(chr(c) for c in [65, 67, 84, 73, 86, 69])
 EFXQGL = "".join(chr(c) for c in [85, 100, 80, 52])
 EGZUQE = 3
@@ -187,10 +186,11 @@ EUHNNX = "".join(
 )
 EUTOPH = "".join(chr(c) for c in [45, 45, 45])
 EXLSXU = "".join(chr(c) for c in [87, 97, 116, 101, 114, 102, 97, 108, 108])
-EZFETD = 256
+EZFETD = 59
 FCRTFM = "".join(chr(c) for c in [75, 51, 48, 48])
 FEFJTA = "".join(chr(c) for c in [78, 69, 87])
 FEGZUQ = "".join(chr(c) for c in [79, 51])
+FETDRX = 479
 FFTTID = 293
 FIKJPU = "".join(chr(c) for c in [83, 79, 117, 116, 49, 48])
 FJBIAM = 377
@@ -838,7 +838,7 @@ YYPIPI = "".join(
 ZBBEKB = 472
 ZCQBMJ = "".join(chr(c) for c in [82, 104, 87, 97, 116, 101, 114, 84, 101, 109, 112])
 ZDGKEA = "".join(chr(c) for c in [83, 68, 105, 114, 101, 99, 116, 67, 117, 114])
-ZFETDR = 479
+ZFETDR = 256
 ZILXWA = "".join(chr(c) for c in [77, 97, 115, 73, 66, 67])
 ZMJIGY = "".join(chr(c) for c in [77, 69, 68])
 ZMKQTD = "".join(chr(c) for c in [67, 70, 71, 50, 48])
@@ -846,6 +846,37 @@ ZTATDZ = "".join(chr(c) for c in [83, 79, 117, 116, 55, 67, 117, 114])
 ZUQEXL = "".join(chr(c) for c in [77, 83, 84, 82, 95, 72, 69, 65, 84, 69, 82])
 ZVOACM = 460
 ZXNQTM = 343
+EEZFET = [
+    QSNQLN,
+    QFYLJU,
+    LJUIKF,
+    OAWBSI,
+    SPBWJY,
+    EJNIBX,
+    BQSNQL,
+    SNQLNM,
+    LGQPLS,
+    BLKXSJ,
+    YXBQFY,
+    BSIRYX,
+    JBIAMJ,
+    TSIFJB,
+    XYBQSN,
+    WBSIRY,
+    XBQFYL,
+    RYXBQF,
+    JMAOAW,
+    JUIKFW,
+    AMJMAO,
+    BIAMJM,
+    FYLJUI,
+    FWRKIN,
+    YLJUIK,
+    IAMJMA,
+    IRYXBQ,
+    AWBSIR,
+    MAOAWB,
+]
 FJTACC = [IUXFEF, UXFEFJ, XFEFJT, FEFJTA, EFJTAC]
 GDSBDJ = [BYGDSB, YGDSBD]
 HWDAFI = [
@@ -1058,16 +1089,16 @@ class GeckoLogStruct:
 
     @property
     def version(self):
-        return EEZFET
-
-    @property
-    def begin(self):
         return EZFETD
 
     @property
-    def end(self):
+    def begin(self):
         return ZFETDR
 
+    @property
+    def end(self):
+        return FETDRX
+
     @property
     def all_device_keys(self):
         return XWEEZF
@@ -1076,6 +1107,10 @@ class GeckoLogStruct:
     def user_demand_keys(self):
         return WEEZFE
 
+    @property
+    def error_keys(self):
+        return EEZFET
+
     @property
     def accessors(self):
         return {
